/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.IO;

namespace Org.Apache.Rocketmq
{
    [TestClass]
    public class ConfigFileCredentialsProviderTest
    {
        [TestInitialize]
        public void Setup()
        {
            var configFilePath = ConfigFileCredentialsProvider.DefaultConfigFilePath();
            FileInfo fileInfo = new FileInfo(configFilePath);
            var dir = fileInfo.Directory;
            if (!dir.Exists)
            {
                dir.Create();
            }

            string json = "{\"AccessKey\": \"key\", \"AccessSecret\": \"secret\"}";
            File.WriteAllText(configFilePath, json);
        }
        
        [TestMethod]
        public void TestGetCredentials()
        {
            var provider = new ConfigFileCredentialsProvider();
            var credentials = provider.getCredentials();
            Assert.IsNotNull(credentials);
            Assert.AreEqual(credentials.AccessKey, "key");
            Assert.AreEqual(credentials.AccessSecret, "secret");
        }

        [TestCleanup]
        public void TearDown()
        {
            var configFilePath = ConfigFileCredentialsProvider.DefaultConfigFilePath();
            File.Delete(configFilePath);
        }
    }
}